﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Windows.Browser;
using System.ComponentModel;

namespace SilverHtmlInteraction
{
	public partial class HostingDivControl : UserControl
	{

		public static DependencyProperty LeftProperty = DependencyProperty.Register("Left", typeof(double), 
														typeof(HostingDivControl), 
														new PropertyMetadata( new PropertyChangedCallback(LeftPropertyChanged) ));

		public static DependencyProperty TopProperty = DependencyProperty.Register("Top", typeof(double), 
														typeof(HostingDivControl),
														new PropertyMetadata(new PropertyChangedCallback(TopPropertyChanged)));



		private static void LeftPropertyChanged(DependencyObject obj, DependencyPropertyChangedEventArgs e)
		{
			if (obj == null)
				return;
			if (obj is HostingDivControl != true)
				return;

			HostingDivControl ctrl = (HostingDivControl)obj;

			ctrl.Left	= (double)e.NewValue;
		}


		private static void TopPropertyChanged(DependencyObject obj, DependencyPropertyChangedEventArgs e)
		{
			if( obj == null)
				return;
			if( obj is HostingDivControl !=true)
				return;

			HostingDivControl	ctrl	= (HostingDivControl) obj;

			ctrl.Top	= (double) e.NewValue;
		}

		private HtmlElement	m_div		= null;
		private string		m_div_id	= "";


		public HostingDivControl()
		{
			InitializeComponent();
		}

		public HostingDivControl( HtmlElement div)
		{
			InitializeComponent();
			Div	= div;
		}

			

		public HtmlElement Div
		{
			get { return m_div; }
			set
			{
				m_div = value;
				if (m_div != null)
				{
					m_div_id	= m_div.Id;
					base.Width	= this.Width;
					base.Height	= this.Height;
					Left		= GetDimension("left", "offsetLeft", 0.0);
					Top			= GetDimension("top", "offsetTop", 0.0);

					if( string.IsNullOrEmpty( m_div.GetStyleAttribute("position")))
						m_div.SetStyleAttribute("position", "relative");
				}
				else
					m_div_id = "";
			}
		}

		protected double GetDimensionProperty(string property_name, double default_value)
		{
			if( m_div == null)
			{
				debug_display_div_error();
				return default_value;
			}
			
			string	str_value	= m_div.GetProperty( property_name).ToString();

			if (string.IsNullOrEmpty(str_value))
			{
				return default_value;
			}
			double value = default_value;

			if (double.TryParse(str_value, out value) == false)
				return default_value;

			return value;
		}

		protected void debug_display_div_error()
		{
			HtmlPage.Window.Alert("Couldn't obtain parent div\r\nDiv.ID=" + m_div_id);
		}

		protected void SetDimentionProperty(string property_name, double value)
		{
			if (m_div == null)
			{
				debug_display_div_error();
				return;
			}
			m_div.SetProperty(property_name, ((int)value).ToString());
		}


		protected double GetDimensionAttribute(string attrib_name, double default_value)
		{
			if (m_div == null)
			{
				debug_display_div_error();
				return default_value;
			}

			// try to get the style attribute value
			string str_value = m_div.GetStyleAttribute(attrib_name);

			if (string.IsNullOrEmpty(str_value))
			{
				return default_value;
			}
			// remove the dimension's unit (px)
			str_value = str_value.Replace("px", "");

			double value = default_value;

			// try to convert to numeric value
			if (double.TryParse(str_value, out value) == false)
				return default_value;
			return value;
		}

		protected void SetDimentionAttribute(string attrib_name, double value)
		{
			if (m_div == null)
			{
				debug_display_div_error();
				return;
			}

			m_div.SetStyleAttribute(attrib_name, ((int)value).ToString() + "px");
		}

		private double GetDimension(string attrib_name, string property_name, double default_value)
		{
			double attrib = GetDimensionAttribute(attrib_name, default_value);

			if (attrib <= 0.0)
				return GetDimensionProperty( property_name, default_value);
			return attrib;
		}


		public new double Width
		{
			get
			{
				if( m_div == null)
					return base.Width;

				double attrib = GetDimension("width", "offsetWidth", 0.0);

				return attrib;
			}
			set
			{
				SetDimentionAttribute("width", value);
				base.Width	= value;
			}
		}

		public new double Height
		{
			get
			{
				if( m_div == null)
					return base.Height;

				double attrib = GetDimension("height", "offsetHeight", 0.0);

				return attrib;
			}
			set
			{
				SetDimentionAttribute("height", (int) value);
				base.Height	= value;
			}
		}

		public double Left
		{
			get
			{
				double attrib = GetDimension("left", "offsetLeft", 0.0);

				return attrib;
			}
			set
			{
				SetDimentionAttribute("left", value);
			}
		}

		public double Top
		{
			get
			{
				double attrib = GetDimension("top", "offsetTop", 0.0);
	
				return attrib;
			}
			set
			{
				SetDimentionAttribute("top", value);
			}
		}

		private void UserControl_SizeChanged(object sender, SizeChangedEventArgs e)
		{
			SetDimentionAttribute("width", e.NewSize.Width);
			SetDimentionAttribute("height", e.NewSize.Height);
		}


	}
}
