﻿
using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Windows.Browser;
using System.ComponentModel;


namespace SilverHtmlInteraction
{
	public partial class MainPage : UserControl
	{

		public MainPage()
		{
			InitializeComponent();

			host_div.Div	= Parent_div;
		}

		private HtmlElement Parent_div
		{
			get
			{
				return HtmlPage.Plugin.Parent;
			}
		}

		private int Parent_div_width
		{
			get
			{
				HtmlElement	my_div		= Parent_div;

				string	str_width	= my_div.GetStyleAttribute("width");

				if( string.IsNullOrEmpty(str_width) == false)
					str_width	= str_width.Replace("px", "");

				int		width		= 0;

				if (int.TryParse(str_width, out width) == false)
					return (int)this.MinWidth;

				return Math.Max( width, (int)this.MinWidth);
			}
		}


		private Storyboard	sb	= null;

		private void CreateStoryBoard()
		{
			if( sb != null)
				return;

			sb			= new Storyboard();
			DoubleAnimationUsingKeyFrames	animx	= new DoubleAnimationUsingKeyFrames(),
											animy	= new DoubleAnimationUsingKeyFrames();
			EasingDoubleKeyFrame			kfx,
											kfy;
			double	x				= host_div.Left, 
					y				= host_div.Top,
					x0				= x,
					y0				= y,
					milliseconds,
					radius			= 40.0;

			//sb.Duration		= TimeSpan.FromSeconds( 6);
			//animx.Duration	= TimeSpan.FromSeconds( 6);
			//animy.Duration	= TimeSpan.FromSeconds( 6);
			
			Storyboard.SetTarget( animx, host_div);
			Storyboard.SetTarget( animy, host_div);
			Storyboard.SetTargetProperty( animx, new PropertyPath( HostingDivControl.LeftProperty));
			Storyboard.SetTargetProperty( animy, new PropertyPath( HostingDivControl.TopProperty));

			kfx	= new EasingDoubleKeyFrame();
			kfy	= new EasingDoubleKeyFrame();

			kfx.KeyTime		= KeyTime.FromTimeSpan( TimeSpan.FromMilliseconds( 0.0));
			kfy.KeyTime		= kfx.KeyTime;
			kfx.Value		= x;
			kfy.Value		= y;

			animx.KeyFrames.Add( kfx);
			animy.KeyFrames.Add( kfy);
			

			for (milliseconds = 100.0; milliseconds <= 3600 ; milliseconds += 100.0)
			{
				y	= radius *  Math.Sin( 30.0 + milliseconds / 360.0) + y0;
				x	= radius *  Math.Cos( 30.0 + milliseconds / 360.0) + x0;
				
				kfx	= new EasingDoubleKeyFrame();
				kfy	= new EasingDoubleKeyFrame();

				kfx.KeyTime		= KeyTime.FromTimeSpan( TimeSpan.FromMilliseconds( milliseconds));
				kfy.KeyTime		= kfx.KeyTime;
				kfx.Value		= x;
				kfy.Value		= y;
				
				animx.KeyFrames.Add( kfx);
				animy.KeyFrames.Add( kfy);
			}
			animx.Duration	= TimeSpan.FromMilliseconds( milliseconds);
			animy.Duration	= animx.Duration;
			sb.Duration		= animx.Duration;

			sb.Children.Add(animx);
			sb.Children.Add(animy);
		}

		private void Animate()
		{
			CreateStoryBoard();
			if( sb.GetCurrentState() == ClockState.Active)
				sb.Stop();
			else
				sb.Begin();
		}


		private void btn_animate_Click(object sender, RoutedEventArgs e)
		{
			//Storyboard1.Begin();
			Animate();
		}

	}
}
